#!/usr/bin/env python
import os, sys

os.environ.setdefault("DJANGO_SETTINGS_MODULE", 'test_app.test_settings')

from optparse import OptionParser
from django_nose.runner import NoseTestSuiteRunner


def runtests(*test_args, **kwargs):

    if not test_args:
        test_args = ['tests']
    test_args.append('--with-spec')
    test_args.append('--spec-color')
    kwargs.setdefault('interactive', False)
    test_runner = NoseTestSuiteRunner(**kwargs)

    failures = test_runner.run_tests(test_args)
    sys.exit(failures)


if __name__ == '__main__':
    parser = OptionParser()
    parser.add_option('--verbosity', dest='verbosity', action='store', default=1, type=int)
    parser.add_options(NoseTestSuiteRunner.options)
    (options, args) = parser.parse_args()

    runtests(*args, **options.__dict__)


if __name__ == '__main__':
    runtests()


from sys import path
import os
from setuptools import setup
#from distutils.core import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name = 'django-smoke-admin',
    version = '0.1.1',
    packages = ['django-smoke-admin'],
    include_package_data = True,
    license = 'MIT License',
    description = 'django-smoke-admin tests that all admin pages for all registered models responds correctly (HTTP 200).',
    long_description = README,
    url = 'https://bitbucket.org/Melevir/django-smoke-admin',
    author = 'Lebedev Ilya',
    author_email = 'melevir@gmail.com',
    classifiers = [
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        ],
)